Token

Struct Token 

pub struct Token<T>
where T: PartialEq + Clone + Debug,
{ pub is_left_joinable: bool, pub is_right_joinable: bool, /* private fields */ }
A token with a normalized form (used for diffing) and an original form (used when applying operations). Joinability flags control whether adjacent insertions interleave or group.

UTF-8 compatible.

Fields

is_left_joinable: bool

Whether the token is semantically joinable with the previous token

is_right_joinable: bool

Whether the token is semantically joinable with the next token

Implementations

Source

impl<T> Token<T>
where T: PartialEq + Clone + Debug,

pub fn new( normalized: T, original: String, is_left_joinable: bool, is_right_joinable: bool, ) -> Self

pub fn original(&self) -> &str

pub fn set_normalized(&mut self, normalized: T)

pub fn normalized(&self) -> &T

pub fn get_original_length(&self) -> usize